==> spip_3.0.18.orig.tar.xz: spip/plugins-dist/mots/lang/mots_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Group empourtant:</b> es fouòrt acounsilhat de seleciounà un mot clau en aqueu group.',
	'avis_doublon_mot_cle' => 'Un mot esistà ja embé aqueu titre. Sias segur de voulé creà lou meme ?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Lu aministratour dóu sit',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'lu redatour',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'lu visitaire dóu sit public quoura pouòston un message en un fòrou.',

	// C
	'creer_et_associer_un_mot' => 'Creà e assoucià un mot clau',

	// I
	'icone_creation_groupe_mots' => 'Creà un group de mot nouvèu',
	'icone_creation_mots_cles' => 'Creà un mot clau nouvèu',
	'icone_modif_groupe_mots' => 'Moudificà aqueu group de mot',
	'icone_modifier_mot' => 'Moudificà aqueu mot clau',
	'icone_mots_cles' => 'Mot clau',
	'icone_supprimer_groupe_mots' => 'Suprimà aqueu group',
	'icone_voir_groupe_mots' => 'Veire aqueu group de mot',
	'icone_voir_tous_mots_cles' => 'Veire toui lu mot clau',
	'info_1_groupe_mots' => '1 group de mot',
	'info_articles_lies_mot' => 'Lu article ligat en aqueu mot clau',
	'info_aucun_groupe_mots' => 'Mìnga group de mot',
	'info_aucun_mot_cle' => 'Mìnga mot clau',
	'info_changer_nom_groupe' => 'Cambià lou noum d’aqueu goup :',
	'info_creation_mots_cles' => 'Creàs e counfiguràs aquì lu mot clau dóu sit',
	'info_dans_groupe' => 'En lou group :',
	'info_delet_mots_cles' => 'Avès demandat da suprimà lou mot clau <b>@titre_mot@</b> (@type_mot@). Couma aqueu mot clau es ligat en <b>@texte_lie@</b> devès counfirmà aqueula dechisioun :',
	'info_groupe_important' => 'Group empourtant',
	'info_modifier_mot' => 'Moudificà lou mot clau',
	'info_mots_cles' => 'Lu mot clau',
	'info_mots_cles_association' => 'Lu mot clau d’aqueu group pouòdon estre assouciat :',
	'info_nb_groupe_mots' => '@nb@ group de mot',
	'info_oui_suppression_mot_cle' => 'vouòli suprimà definitivamen aqueu mot clau.',
	'info_question_mots_cles' => 'Auguràs utilisà lu mot clau sus lou vouòstre sit ?',
	'info_qui_attribue_mot_cle' => 'Lu mot d’aqueu group pouòdon estre atribuit per :',
	'info_remplacer_mot' => 'Remplaçà "@titre@"',
	'info_retirer_mot' => 'Retirà aqueu mot',
	'info_retirer_mots' => 'Retirà toui lu mot',
	'info_rubriques_liees_mot' => 'Li rùbrica ligadi en aqueu mot clau',
	'info_selection_un_seul_mot_cle' => 'Si pòu seleciounà qu’un mot clau <b>soulèt</b> a l’encòu en aqueu group.',
	'info_supprimer_mot' => 'suprimà aqueu mot',
	'info_titre_mot_cle' => 'Noum o titre dóu mot clau',
	'info_un_mot' => 'Basta un mot a l’encòu',
	'item_ajout_mots_cles' => 'Autourisà l’ajountamen de mot clau ai fòrou',
	'item_non_ajout_mots_cles' => 'Prouhibì l’utilisacioun dei mot clau en lu fòrou',
	'item_non_utiliser_config_groupe_mots_cles' => 'Noun utilisà la counfiguracioun avançada dei group de mot clau',
	'item_non_utiliser_mots_cles' => 'Noun utilisà lu mot clau',
	'item_utiliser_config_groupe_mots_cles' => 'Utilisà la counfiguracioun avançada dei group de mot clau',
	'item_utiliser_mots_cles' => 'Utilisà lu mot clau',

	// L
	'lien_ajouter_mot' => 'Ajustà aqueu mot clau',
	'logo_groupe' => 'LOGOU D’AQUEU GROUP',
	'logo_mot_cle' => 'LOGOU DÓU MOT CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'Auguràs d’ativà la counfiguracioun avançada dei mot clau, en endicant per isemple que si pòu seleciounà un mot soulet per group, qu’un group es empourtant… ?',
	'texte_mots_cles' => 'Lu mot clau permeton da creà dei estac temàticou tra lu vouòstre article
		quauque que sigue la sieu plaça en li rùbrica. Acò vi permete
		d’enriquì la navigacioun dóu vouòstre sit, e mai d’utilisà aqueli prouprietà
		da persounalisà la presentacioun dei article en li esquèletrou.',
	'texte_mots_cles_dans_forum' => 'Auguràs de permetre l’utilisacioun de mot clau seleciounable dai visitaire en lu fòrou dóu sit public ? (Mèfi : utilisà courretamen aquela oupcioun es proun coumplesse.)',
	'texte_nouveau_mot' => 'Mot nouvèu',
	'titre_config_groupe_mots_cles' => 'Configuracioun dei group de mot clau',
	'titre_gauche_mots_edit' => 'MOT NÙMERO :',
	'titre_groupe_mots' => 'Group de mot clau',
	'titre_groupe_mots_numero' => 'GROUP DE MOT NÙMERO :',
	'titre_groupes_mots' => 'Group de mot clau',
	'titre_mots_cles_dans_forum' => 'Mot clau en lu fòrou dóu sit public',
	'titre_mots_tous' => 'Lu mot clau',
	'titre_nouveau_groupe' => 'Group nouvèu',
	'titre_objets_lies_mot' => 'Ligat en aqueu mot clau :',
	'titre_page_mots_tous' => 'Mot clau'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/mots/lang/mots_oc_ni_mis.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mots?lang_cible=oc_ni_mis
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'avis_conseil_selection_mot_cle' => '<b>Group empourtant :</b> es fouòrt acounsilhat de seleciounà un mot clau en aqueu group.',
	'avis_doublon_mot_cle' => 'Un mot esistà ja embé aqueu titre. Sias segur de voulé creà lou meme ?',

	// B
	'bouton_checkbox_qui_attribue_mot_cle_administrateurs' => 'Lu aministratour dóu sit',
	'bouton_checkbox_qui_attribue_mot_cle_redacteurs' => 'lu redatour',
	'bouton_checkbox_qui_attribue_mot_cle_visiteurs' => 'lu visitaire dóu sit pùblicou coura pouòston un message en un fòrou.',

	// C
	'creer_et_associer_un_mot' => 'Creà e assoucià un mot clau',

	// I
	'icone_creation_groupe_mots' => 'Creà un nouvèu group de mot',
	'icone_creation_mots_cles' => 'Creà un mot clau nouvèu',
	'icone_modif_groupe_mots' => 'Moudificà aqueu group de mot',
	'icone_modifier_mot' => 'Moudificà aqueu mot clau',
	'icone_mots_cles' => 'Mot clau',
	'icone_supprimer_groupe_mots' => 'Suprimà aqueu group',
	'icone_voir_groupe_mots' => 'Veire aqueu group de mot',
	'icone_voir_tous_mots_cles' => 'Veire toui lu mot clau',
	'info_1_groupe_mots' => '1 group de mot',
	'info_articles_lies_mot' => 'Lu article ligat en aqueu mot clau',
	'info_aucun_groupe_mots' => 'Mìnga group de mot',
	'info_aucun_mot_cle' => 'Mìnga mot clau',
	'info_changer_nom_groupe' => 'Cambià lou noum d’aqueu goup :',
	'info_creation_mots_cles' => 'Creàs e counfiguràs aquì lu mot clau dóu sit',
	'info_dans_groupe' => 'En lou group :',
	'info_delet_mots_cles' => 'Avès demandat de suprimà lou mot clau <b>@titre_mot@</b> (@type_mot@). Couma aqueu mot clau es ligat en <b>@texte_lie@</b> devès counfirmà aqueula dechisioun :',
	'info_groupe_important' => 'Group empourtant',
	'info_modifier_mot' => 'Moudificà lou mot clau',
	'info_mots_cles' => 'Lu mot clau',
	'info_mots_cles_association' => 'Lu mot clau d’aqueu group pouòdon estre assouciat :',
	'info_nb_groupe_mots' => '@nb@ group de mot',
	'info_oui_suppression_mot_cle' => 'vouòli suprimà definitivamen aqueu mot clau.',
	'info_question_mots_cles' => 'Auguràs utilisà lu mot clau sus lou vouòstre sit ?',
	'info_qui_attribue_mot_cle' => 'Lu mot d’aqueu group pouòdon estre atribuit per :',
	'info_remplacer_mot' => 'Remplaçà "@titre@"',
	'info_retirer_mot' => 'Retirà aqueu mot',
	'info_retirer_mots' => 'Retirà toui lu mot',
	'info_rubriques_liees_mot' => 'Li rùbrica ligadi en aqueu mot clau',
	'info_selection_un_seul_mot_cle' => 'Si pòu seleciounà qu’un mot clau <b>soulèt</b> a l’encòu en aqueu group.',
	'info_supprimer_mot' => 'suprimà aqueu mot',
	'info_titre_mot_cle' => 'Noum o titre dóu mot clau',
	'info_un_mot' => 'Basta un mot a l’encòu',
	'item_ajout_mots_cles' => 'Autourisà l’ajountamen de mot clau ai fòrou',
	'item_non_ajout_mots_cles' => 'Prouhibì l’utilisacioun dei mot clau en lu fòrou',
	'item_non_utiliser_config_groupe_mots_cles' => 'Noun utilisà la counfiguracioun avançada dei group de mot clau',
	'item_non_utiliser_mots_cles' => 'Noun utilisà lu mot clau',
	'item_utiliser_config_groupe_mots_cles' => 'Utilisà la counfiguracioun avançada dei group de mot clau',
	'item_utiliser_mots_cles' => 'Utilisà lu mot clau',

	// L
	'lien_ajouter_mot' => 'Ajustà aqueu mot clau',
	'logo_groupe' => 'LOGOU D’AQUEU GROUP',
	'logo_mot_cle' => 'LOGOU DÓU MOT CLAU',

	// T
	'texte_config_groupe_mots_cles' => 'Auguràs d’ativà la counfiguracioun avançada dei mot clau, en endicant per isemple que si pòu seleciounà un mot soulet per group, qu’un group es empourtant… ?',
	'texte_mots_cles' => 'Lu mot clau permeton de creà dei estac temàticou tra lu vouòstre article
		quauque que sigue la sieu plaça en li rùbrica. Acò vi permete
		d’enriquì la navigacioun dóu vouòstre sit, e mai d’utilisà aqueli prouprietà
		per persounalisà la presentacioun dei article en li esquèletrou.',
	'texte_mots_cles_dans_forum' => 'Auguràs de permetre l’utilisacioun de mot clau seleciounable dai visitaire en lu fòrou dóu sit public ? (Mèfi : utilisà courretamen aquela oupcioun es proun coumplesse.)',
	'texte_nouveau_mot' => 'Mot nouvèu',
	'titre_config_groupe_mots_cles' => 'Configuracioun dei group de mot clau',
	'titre_gauche_mots_edit' => 'MOT NÙMERO :',
	'titre_groupe_mots' => 'Group de mot clau',
	'titre_groupe_mots_numero' => 'GROUP DE MOT NÙMERO :',
	'titre_groupes_mots' => 'Group de mot clau',
	'titre_mots_cles_dans_forum' => 'Mot clau en lu fòrou dóu sit public',
	'titre_mots_tous' => 'Lu mot clau',
	'titre_nouveau_groupe' => 'Group nouvèu',
	'titre_objets_lies_mot' => 'Ligat en aqueu mot clau :',
	'titre_page_mots_tous' => 'Mot clau'
);

?>
